/*
 * Mach Operating System
 * Copyright (c) 1992 Carnegie Mellon University
 * All Rights Reserved.
 *
 * Permission to use, copy, modify and distribute this software and its
 * documentation is hereby granted, provided that both the copyright
 * notice and this permission notice appear in all copies of the
 * software, derivative works or modified versions, and any portions
 * thereof, and that both notices appear in supporting documentation.
 *
 * CARNEGIE MELLON ALLOWS FREE USE OF THIS SOFTWARE IN ITS "AS IS"
 * CONDITION.  CARNEGIE MELLON DISCLAIMS ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 *
 * Carnegie Mellon requests users of this software to return to
 *
 *  Software Distribution Coordinator  or  Software.Distribution@CS.CMU.EDU
 *  School of Computer Science
 *  Carnegie Mellon University
 *  Pittsburgh PA 15213-3890
 *
 * any improvements or extensions that they make and grant Carnegie Mellon
 * the rights to redistribute these changes.
 */
/*
 * Amiga interrupt handler entrypoints, called from m68k/locore.s
 *
 * Contributors:
 *      Markus Wild
 */

#include <machine/frame.h>
#include <machine/custom.h>
#include <machine/mach_param.h>
#include <machine/cia.h>

/* We're using Timer A, CIA-B as hardclock, since the int-level 6 fits 
   nicely into Vax-interrupt-architecture ;-) */

void
startrtclock(void)
{
  unsigned short interval;

  /* FIXME for now assume NTSC timing... (although I'm European;-)) */

  /* stop timer A */
  ciab.cra = ciab.cra & 0xc0;

  /* load interval into registers.
     the clocks run at NTSC: 715.909kHz or PAL: 709.379kHz */

  interval = 715909 / HZ;

  /* order of setting is important ! */
  ciab.talo = interval & 0xff;
  ciab.tahi = interval >> 8;

  /* enable interrupts for timer A */
  ciab.icr = (1<<7) | (1<<0);

  /* start timer A in continuous shot mode */
  ciab.cra = (ciab.cra & 0xc0) | 1;
  
  printf ("ciab-clock running\n");
}


void
resettodr(void)
{
}

/*
void inittodr(void)
{
}
*/
